@@ -5,13 +5,13 @@
  * Copyright (C) 1999, 2000 Jaakko Heinonen
  */
 
-#include <ncurses.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <signal.h>
 #include <fcntl.h>
+#include "abook_curses.h"
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif
@@ -154,7 +154,6 @@ quit_abook()
 	}
 	close_config();
 	close_database();
-	free_filenames();
 	close_list();
 	free_windows();
 	clear();
@@ -196,6 +195,8 @@ set_filenames()
 		datafile = strconcat(getenv("HOME"), "/" DATAFILE, NULL);
 
 	rcfile = strconcat(getenv("HOME"), "/" RCFILE, NULL);
+
+	atexit(free_filenames);
 }
 
 static void
@@ -212,9 +213,8 @@ headerline(char *str)
 
 	werase(top);
 	
-	for( i=0 ; i < COLS ; i++ ) {
+	for( i=0 ; i < COLS ; i++ )
 		mvwaddch(top, 1, i, '-');
-	}
 	
 	mvwprintw(top, 0, 0, "%s | %s", PACKAGE " " VERSION, str);
 
@@ -319,7 +319,7 @@ get_commands()
 			case ' ': if(curitem >= 0) {
 				   selected[curitem] = !selected[curitem];
 				   print_number_of_items();
-				   refresh_curitem(curitem);
+				   refresh_list();
 				  }
 				break;
 			case '+': select_all();
@@ -784,27 +784,33 @@ convert(char *srcformat, char *srcfile, char *dstformat, char *dstfile)
 		exit(1);
 	}
 
+	set_filenames();
+	init_options();
+
 	switch( import(srcformat, srcfile) ) {
 		case -1:
 			printf("input format %s not supported\n", srcformat);
-			exit(1);
+			ret = 1;
 		case 1:
 			printf("cannot read file %s\n", srcfile);
-			exit(1);
+			ret = 1;
 	}
 
-	switch( export(dstformat, dstfile) ) {
-		case -1:
-			printf("output format %s not supported\n", dstformat);
-			ret = 1;
-			break;
-		case 1:
-			printf("cannot write file %s\n", dstfile);
-			ret = 1;
-			break;
-	}
+	if(!ret)
+		switch( export(dstformat, dstfile) ) {
+			case -1:
+				printf("output format %s not supported\n",
+						dstformat);
+				ret = 1;
+				break;
+			case 1:
+				printf("cannot write file %s\n", dstfile);
+				ret = 1;
+				break;
+		}
 
 	close_database();
+	close_config();
 	exit(ret);
 }
 
