@@ -21,7 +21,7 @@
  */
 
 /*
- * conff.c version 0.2.10
+ * conff.c version 0.2.11
  */
 
 #include <stdio.h>
@@ -384,8 +384,11 @@ conff_load_config(conffile *file, char *filename, const int flags)
 			}
 		} else
 		if ( (tmp = strchr(line, '=') ) && sec != NULL ) {
-			*tmp = '\0';
-			conff_add_key(file, sec , line, ++tmp);
+			*tmp++ = '\0';
+			if(flags & CONFF_LOAD_NOREPLACE)
+				conff_add_key_noreplace(file, sec , line, tmp);
+			else
+				conff_add_key(file, sec , line, tmp);
 		}
 		else {
 /*			fprintf(stderr, "parse error2,line #%d\n",i);*/
