@@ -6,12 +6,12 @@
  * Copyright (C) Jaakko Heinonen
  */
 
-#include <ncurses.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include "abook_curses.h"
 #include "abook.h"
 #include "database.h"
 #include "list.h"
@@ -36,8 +36,6 @@ extern char *selected;
 extern char *datafile;
 extern char *rcfile;
 
-#define MAX_LINESIZE 400
-
 /*
  * field definitions
  */
@@ -64,10 +62,17 @@ struct abook_field abook_fields[ITEM_FIELDS] = {
 	{"Work Phone",	"workphone",	TAB_PHONE},/* WORKPHONE */
 	{"Fax",		"fax",		TAB_PHONE},/* FAX */
 	{"Mobile",	"mobile",	TAB_PHONE},/* MOBILEPHONE */
+#if 0
+	{"Nickname/Alias", "nick",      TAB_OTHER},/* NICK */
+#endif
 	{"URL",		"url",		TAB_OTHER},/* URL */
 	{"Notes",	"notes",	TAB_OTHER},/* NOTES */
 };
 
+
+
+#define MAX_LINESIZE	400
+
 int
 parse_database(FILE *in)
 {
@@ -91,20 +96,16 @@ parse_database(FILE *in)
 
 		if( !*line || *line == '\n' || *line == '#' )
 			continue;
-		else
-		if( *line == '[' ) {
+		else if( *line == '[' ) {
 			if( item[NAME] && sec )
 				add_item2database(item);
 			else
 				free_list_item(item);
 			memset(&item, 0, sizeof(item));
 			sec = 1;
-			if ( !(tmp = strchr(line, ']'))) {
+			if ( !(tmp = strchr(line, ']')))
 				sec = 0; /*incorrect section lines are skipped*/
-			}
-		}
-		else
-		if((tmp = strchr(line, '=') ) && sec ) {
+		} else if((tmp = strchr(line, '=') ) && sec ) {
 			*tmp = '\0'; tmp++;
 			for(i=0; i<ITEM_FIELDS; i++)
 				if( !strcmp(abook_fields[i].key, line) )
@@ -133,8 +134,6 @@ load_database(char *filename)
 	if ( items == 0 )
 		return 2;
 
-	check_list();
-
 	return 0;
 }
 
@@ -188,10 +187,7 @@ save_database()
 static void
 free_item(int item)
 {
-	int i;
-
-	for(i=0; i<ITEM_FIELDS; i++)
-		my_free(database[item][i]);
+	free_list_item(database[item]);
 }
 
 void
@@ -292,20 +288,17 @@ remove_items()
 		}
 	}
 
-	if( curitem > LAST_ITEM && items > 0 ) {
+	if( curitem > LAST_ITEM && items > 0 )
 		curitem = LAST_ITEM;
-		if( first_list_item > LAST_ITEM )
-			first_list_item = max(items - LIST_LINES, 0);
-	}
+
 
 	if(items > 0) {
 		database = abook_realloc(database,
 				sizeof(list_item) * items);
 		selected = abook_realloc(selected, items);
-	} else {
+	} else
 		close_database();
-		curitem = first_list_item = -1;
-	}
+
 	select_none();
 	clear_statusline();	
 	refresh_list();
@@ -425,8 +418,6 @@ find(int next)
 		strcpy(tmp, database[i][NAME]);
 		if( strstr(strupper(tmp), findstr) != NULL ) {
 			curitem = i;
-			if(curitem > LAST_LIST_ITEM)
-				first_list_item = curitem;
 			refresh_list();
 			break;
 		}
