@@ -3,7 +3,7 @@
 
 
 #define MAX_EMAILS		4
-#define MAX_EMAIL_LEN		40
+#define MAX_EMAIL_LEN		80
 #define MAX_EMAILSTR_LEN	(MAX_EMAILS*MAX_EMAIL_LEN + MAX_EMAILS + 1)
 #define MAX_FIELD_LEN		81
 
@@ -18,8 +18,14 @@
 #define WORKPHONE		8
 #define FAX			9
 #define MOBILEPHONE		10
-#define URL			11
-#define NOTES			12
+#if 0
+#define NICK			11
+#define URL			12
+#define NOTES			13
+#else
+#define URL                     11
+#define NOTES                   12
+#endif
 
 #define LAST_FIELD		NOTES
 
@@ -52,11 +58,6 @@ void		print_database();
 
 #define LAST_ITEM	(items - 1)
 
-#include <ncurses.h>
-#ifndef	getnstr
-#	define getnstr(s, n)           wgetnstr(stdscr, s, n)
-#endif
-
 #define itemcpy(dest, src)	memmove(dest, src, sizeof(list_item))
 
 #define split_emailstr(item, emails) {\
