@@ -17,23 +17,30 @@
 /*#undef ABOOK_SRC*/
 
 #include <stdlib.h>
-#include <ncurses.h>
 #include <ctype.h>
 #include <string.h>
-#include "estr.h"
 #ifdef ABOOK_SRC
+#	include "abook_curses.h"
 #	include "options.h"
+#else
+#	include <ncurses.h>
 #endif
+#ifdef HAVE_CONFIG_H
+#	include "config.h"
+#endif
+#include "estr.h"
 
 #if defined(HAVE_LOCALE_H) || defined(HAVE_SETLOCALE)
 #	include <locale.h>
 #else
 /*
- * this is a quick and dirty hack and it is 
+ * this is a quick and dirty hack and it is
  * not likely to work well
  */
 #	undef iscntrl
-#	define iscntrl(X)	(X < 32)
+#	undef isprint
+#	define iscntrl(X)       (X < 32)
+#	define isprint(X)	(!iscntrl(X))
 #endif
 
 /*
@@ -139,12 +146,10 @@ out:
  */
 
 #include <stdio.h>
-#include <string.h>
 #include <dirent.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <ncurses.h>
 
 
 #define FILESEL_STATUSLINE      2
@@ -193,9 +198,6 @@ my_getcwd()
 #endif
 
 
-#include <ncurses.h>
-
-
 #define FILESEL_LAST_ITEM       (filesel_items -1)
 
 int filesel_curitem = -1;
@@ -339,8 +341,7 @@ filesel_refresh_statusline()
 	char *p = NULL;
 	
 	move(FILESEL_STATUSLINE,0);
-	deleteln();
-	insertln();
+	clrtoeol();
 
 	mvaddnstr(FILESEL_STATUSLINE, 5,
 			( p = my_getcwd() ), COLS-5 );
