@@ -9,19 +9,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ncurses.h>
 #include <pwd.h>
 #include <sys/types.h>
+#include "abook_curses.h"
 #include "filter.h"
 #include "abook.h"
 #include "database.h"
 #include "edit.h"
 #include "list.h"
 #include "misc.h"
+#include "options.h"
 
 extern int items;
-extern int curitem;
-extern int first_list_item;
 extern list_item *database;
 extern struct abook_field abook_fields[];
 
@@ -32,6 +31,7 @@ extern struct abook_field abook_fields[];
 static int      ldif_parse_file(FILE *handle);
 static int	pine_parse_file(FILE *in);
 
+static int      ldif_export_database(FILE *out);
 static int	html_export_database(FILE *out);
 static int	pine_export_database(FILE *out);
 static int	csv_export_database(FILE *out);
@@ -39,6 +39,8 @@ static int	gcrd_export_database(FILE *out);
 static int	mutt_alias_export(FILE *out);
 static int	elm_alias_export(FILE *out);
 static int	text_export_database(FILE *out);
+static int	spruce_export_database(FILE *out);
+
 
 struct abook_filter i_filters[] = {
 	{ "abook", "abook native format", parse_database },
@@ -49,6 +51,7 @@ struct abook_filter i_filters[] = {
 
 struct abook_filter e_filters[] = {
 	{ "abook", "abook native format", write_database },
+	{ "ldif", "ldif / Netscape addressbook (.4ld)", ldif_export_database },
 	{ "mutt", "mutt alias", mutt_alias_export },
 	{ "html", "html document", html_export_database },
 	{ "pine", "pine addressbook", pine_export_database },
@@ -56,6 +59,7 @@ struct abook_filter e_filters[] = {
 	{ "csv", "comma separated values", csv_export_database },
 	{ "elm", "elm alias", elm_alias_export },
 	{ "text", "plain text", text_export_database },
+	{ "spruce", "Spruce address book", spruce_export_database },
 	{ "\0", NULL, NULL }
 };
 
@@ -94,8 +98,9 @@ number_of_filters(struct abook_filter * filters)
 }
 
 static char *
-get_real_name(char *username)
+get_real_name()
 {
+	char *username = getenv("USER");
 	struct passwd *pwent;
 	int rtn;
 	char *tmp;
@@ -168,7 +173,6 @@ import_database()
 	if( tmp == items )
 		statusline_msg("Hmm.., file seems not to be a valid file");
 	
-	check_list();
 	refresh_screen();
 	free(filename);
 
@@ -220,8 +224,6 @@ import(char filtname[FILTNAME_LEN], char *filename)
 	if( tmp == items )
 		ret = 1;
 	
-	check_list();
-
 	return ret;
 }
 
@@ -461,8 +463,7 @@ ldif_add_item(ldif_item ldif_item)
 
 	memset(abook_item, 0, sizeof(abook_item));
 	
-	if( safe_strcmp(ldif_item[LDIF_ITEM_FIELDS -1], "person") &&
-			ldif_item[LDIF_ITEM_FIELDS -1] )
+	if( !ldif_item[LDIF_ITEM_FIELDS -1] )
 		goto bail_out;
 	
 
@@ -491,6 +492,9 @@ ldif_convert(ldif_item item, char *type, char *value)
 
 	for(i=0; i < LDIF_ITEM_FIELDS; i++) {
 		if( !safe_strcmp(ldif_field_names[i], type) && *value ) {
+			if( i == LDIF_ITEM_FIELDS -1) /* this is a dirty hack */
+				if( safe_strcmp("person", value))
+					break;
 			if(item[i])
 				my_free(item[i]);
 			item[i] = strdup(value);
@@ -546,6 +550,61 @@ ldif_fix_string(char *str)
  * end of ldif import
  */
 
+/*
+ * ldif export filter
+ */
+
+static void
+ldif_fput_type_and_value(FILE *out,char *type, char *value )
+{
+	char *tmp;
+
+	tmp = ldif_type_and_value(type, value, strlen(value));
+
+	fputs(tmp, out);
+
+	free(tmp);
+}
+
+static int
+ldif_export_database(FILE *out)
+{
+	int i;
+	char email[MAX_EMAILSTR_LEN];
+
+	fprintf(out, "version: 1\n");
+	for(i=0; i<items; i++) {
+		char *tmp;
+		int j;
+		get_first_email(email, i);
+
+		tmp = mkstr("cn=%s,mail=%s", database[i][NAME], email);
+		ldif_fput_type_and_value(out, "dn", tmp);
+		free(tmp);
+
+		for(j=0; j < LDIF_ITEM_FIELDS; j++) {
+			if(ldif_conv_table[j] >= 0) {
+				if(ldif_conv_table[j] == EMAIL)
+					ldif_fput_type_and_value(out,
+						ldif_field_names[j], email);
+				else if(database[i][ldif_conv_table[j]])
+					ldif_fput_type_and_value(out,
+						ldif_field_names[j],
+						database[i][ldif_conv_table[j]]);
+			}
+		}
+
+		fprintf(out, "objectclass: top\n"
+				"objectclass: person\n\n");
+	}
+
+	return 0;
+}
+
+/*
+ * end of ldif export filter
+ */
+
 /*
  * html export filter
  */
@@ -585,7 +644,7 @@ html_export_write_head(FILE *out)
 {
 	char *realname;
 
-	realname = get_real_name(getenv("USER"));
+	realname = get_real_name();
 
 	fprintf(out, "<html>\n<head>\n	<title>%s's addressbook</title>",
 			realname );
@@ -830,9 +889,15 @@ gcrd_export_database(FILE *out)
 				safe_str(database[i][COUNTRY])
 				);
 		
-		if ( database[i][PHONE] ) 
-			fprintf(out, "TEL:%s\n", safe_str(database[i][PHONE]));
-		
+		if (database[i][PHONE])
+			fprintf(out, "TEL;HOME:%s\n", database[i][PHONE]);
+		if (database[i][WORKPHONE])
+			fprintf(out, "TEL;WORK:%s\n", database[i][WORKPHONE]);
+		if (database[i][FAX])
+			fprintf(out, "TEL;FAX:%s\n", database[i][FAX]);
+		if (database[i][MOBILEPHONE])
+			fprintf(out, "TEL;CELL:%s\n", database[i][MOBILEPHONE]);
+
 		if ( database[i][EMAIL] ) {
 			split_emailstr(i, emails);
 			for(j=0; j < MAX_EMAILS ; j++) {
@@ -843,7 +908,9 @@ gcrd_export_database(FILE *out)
 		}
 		
 		if ( database[i][NOTES] ) 
-			fprintf(out, "NOTE:%s\n", safe_str(database[i][NOTES]));
+			fprintf(out, "NOTE:%s\n", database[i][NOTES]);
+		if (database[i][URL])
+			fprintf(out, "URL:%s\n",  database[i][URL]);
 
 		fprintf(out, "END:VCARD\n\n");
 		
@@ -910,50 +977,95 @@ mutt_alias_export(FILE *out)
  */
 
 static int
-text_export_database(FILE *out)
+text_export_database(FILE * out)
 {
 	char emails[MAX_EMAILS][MAX_EMAIL_LEN];
 	int i, j;
-	char *realname;
-
-	realname = get_real_name(getenv("USER"));
-
-	fprintf(out, "%s's addressbook\n\n", realname);
+	char *realname = get_real_name();
+	char *style = options_get_str("address", "style");
 
+	fprintf(out,
+		"-----------------------------------------\n%s's address book\n"
+		"-----------------------------------------\n\n\n",
+		realname);
 	free(realname);
 
-	for(i=0; i < items; i++ ) {
-		fprintf(out, "-----------------------------------------"
-				"\n%s\n\n",
-				safe_str(database[i][NAME]));
+	for (i = 0; i < items; i++) {
+		fprintf(out,
+			"-----------------------------------------\n\n");
+		fprintf(out, "%s", database[i][NAME]);
+		fprintf(out, "\n");
 
-		if( *database[i][EMAIL] ) {
+		if (*database[i][EMAIL]) {
+			fprintf(out, "\n");
 			split_emailstr(i, emails);
-			for(j=0; j < MAX_EMAILS ; j++) {
-				if ( *emails[j] )
+			for (j = 0; j < MAX_EMAILS; j++)
+				if (*emails[j])
 					fprintf(out, "%s\n", emails[j]);
+		}
+		/* Print address */
+		if (database[i][ADDRESS]) {
+			if (!safe_strcmp(style, "us")) {	/* US like */
+				fprintf(out, "\n%s", database[i][ADDRESS]);
+				if (database[i][CITY])
+					fprintf(out, "\n%s",
+						database[i][CITY]);
+				if (database[i][STATE] || database[i][ZIP])
+					fprintf(out, "\n%s %s",
+						safe_str(database[i]
+							 [STATE]),
+						safe_str(database[i]
+							 [ZIP]));
+				if (database[i][COUNTRY])
+					fprintf(out, "\n%s",
+						database[i][COUNTRY]);
 			}
-			fputc('\n', out);
+
+			else if (!safe_strcmp(style, "uk")) {	/* UK like */
+				for (j = ADDRESS; j <= COUNTRY; j++)
+					if (database[i][j])
+						fprintf(out, "\n%s",
+							database[i][j]);
+			} else {	/* EU like */
+				fprintf(out, "\n%s", database[i][ADDRESS]);
+				if (database[i][ZIP] || database[i][CITY])
+					fprintf(out, "\n%s %s",
+						safe_str(database[i][ZIP]),
+						safe_str(database[i]
+							 [CITY]));
+				if (database[i][STATE])
+					fprintf(out, "\n%s",
+						database[i][STATE]);
+				if (database[i][COUNTRY])
+					fprintf(out, "\n%s",
+						database[i][COUNTRY]);
+			}
+
+			fprintf(out, "\n");
 		}
 
-		if ( database[i][ADDRESS] ) {
-			for(j=2; j < 7; j++)
-				if ( database[i][j] )
-					fprintf(out, "%s\n", database[i][j]);
-			fputc('\n', out);
+		if ((database[i][PHONE]) || (database[i][WORKPHONE]) ||
+		    (database[i][FAX]) || (database[i][MOBILEPHONE])) {
+			fprintf(out, "\n");
+			for (j = PHONE; j <= MOBILEPHONE; j++)
+				if (database[i][j])
+					fprintf(out, "%s: %s\n",
+						abook_fields[j].name,
+						database[i][j]);
 		}
-				
-		for(j=PHONE; j <= MOBILEPHONE; j++)
-			if ( database[i][j] )
-				fprintf(out, "%s: %s\n", abook_fields[j].name, database[i][j]);
-		fputc('\n', out);
 
-		if ( database[i][NOTES] )
-			fprintf(out, "%s\n\n", database[i][NOTES]);
+		if (database[i][URL])
+			fprintf(out, "\n%s\n", database[i][URL]);
+		if (database[i][NOTES])
+			fprintf(out, "\n%s\n", database[i][NOTES]);
 
+		fprintf(out, "\n");
 	}
+
 	fprintf(out, "-----------------------------------------\n");
 
+	free(style);
+	
 	return 0;
 }
 
@@ -961,7 +1073,6 @@ text_export_database(FILE *out)
  * end of printable export filter
  */
 
-
 /*
  * elm alias export filter
  */
@@ -991,3 +1102,37 @@ elm_alias_export(FILE *out)
  * end of elm alias export filter
  */
 
+
+/*
+ * Spruce export filter
+ */
+
+static int
+spruce_export_database (FILE *out)
+{
+	int i;
+	char email[MAX_EMAIL_LEN];
+
+	fprintf (out, "# This is a generated file made by abook for the Spruce e-mail client.\n\n");
+
+	for (i= 0; i< items; i++) {
+		if(strcmp (safe_str(database[i][EMAIL]), "")) {
+			get_first_email(email, i);
+			fprintf(out, "# Address %d\nName: %s\nEmail: %s\nMemo: %s\n\n",
+					i,
+					database[i][NAME],
+					email,
+					safe_str(database[i][NOTES])
+					);
+		}
+	}
+
+	fprintf (out, "# End of address book file.\n");
+
+	return 0;
+}
+
+/*
+ * end of Spruce export filter
+ */
+
