@@ -6,9 +6,9 @@
  * Copyright (C) Jaakko Heinonen
  */
 
-#include <ncurses.h>
 #include <stdio.h>
 #include <string.h>
+#include "abook_curses.h"
 #include "abook.h"
 #include "database.h"
 #include "edit.h"
@@ -49,55 +49,37 @@ refresh_list()
 
 	print_number_of_items();
 	
-	if( first_list_item < 0 || items < 1 ) {
+	if( items < 1 ) {
 		refresh();
 		wrefresh(list);
 		return;
 	}
+	
+	if(curitem < 0)
+		curitem = 0;
+
+	if(first_list_item < 0)
+		first_list_item = 0;
+
+	if(curitem < first_list_item)
+		first_list_item = curitem;
+	else if(curitem > LAST_LIST_ITEM)
+		first_list_item = max(curitem - LIST_LINES + 1, 0);
 
         for( line = 0, i = first_list_item ; i <= LAST_LIST_ITEM && i < items;
 			line++, i++ ) {
 
 		if(i == curitem)
 			highlight_line(list, line);
-		else
-			wattrset(list, 0);
 		
 		print_list_line(i, line);
+
+		wstandend(list);
         }
 
         wrefresh(list);
 }
 
-void
-refresh_curitem(int olditem)
-{
-	int i, line;
-
-	if( curitem < 0 || olditem < 0 || items==0 )
-		return;
-
-	for( line = 0, i = first_list_item ; i <= LAST_LIST_ITEM && i < items;
-			                        line++, i++ ) {
-
-		if( i == olditem ) {
-			wattrset(list, 0);
-			wmove(list, line, 0);
-			wclrtoeol(list);
-			print_list_line(i, line);
-		}
-		if ( i == curitem ) {
-			wmove(list, line, 0);
-			wclrtoeol(list);
-			highlight_line(list, line);
-			print_list_line(i, line);
-		}
-	}
-
-	wrefresh(list);	
-}
-
-
 void
 print_list_line(int i, int line)
 {
@@ -119,7 +101,8 @@ print_list_line(int i, int line)
 
 	if(extra_column > 2 && extra_column < ITEM_FIELDS)
 		mvwaddnstr(list, line, EXTRAPOS,
-				database[i][extra_column], EXTRALEN);
+				safe_str(database[i][extra_column]),
+				EXTRALEN);
 
 	scrollok(list, TRUE);
 }
@@ -144,14 +127,10 @@ scroll_up()
 {
 	if( curitem < 1 )
 		return;
+
 	curitem--;
 
-	if( first_list_item > 0 && curitem < first_list_item ) {
-		first_list_item--;
-		wscrl(list, -1);
-	}
-	
-	refresh_curitem(curitem + 1);
+	refresh_list();
 }
 
 void
@@ -159,62 +138,39 @@ scroll_down()
 {
 	if( curitem > items - 2 )
 		return;
+
 	curitem++;
 
-	if( curitem > LAST_LIST_ITEM ) {
-		first_list_item++;
-		wscrl(list, 1);
-	}
-	
-	refresh_curitem(curitem - 1);
+	refresh_list();
 }
 
 
 void
 page_up()
 {
-	int old_curitem = curitem;
-
 	if( curitem < 1 )
 		return;
 	
-	if( curitem == first_list_item ) {
-		curitem = (curitem -= LIST_LINES) < 0 ? 0 : curitem;
-		first_list_item = curitem;
-		refresh_list();
-	} else {
-		curitem = first_list_item;
-		refresh_curitem(old_curitem);
-	}
+	curitem = curitem == first_list_item ?
+		((curitem -= LIST_LINES) < 0 ? 0 : curitem) : first_list_item;
+	
+	refresh_list();
 }
 
 void
 page_down()
 {
-	int old_curitem = curitem;
-
 	if( curitem > items - 2 )
 		return;
 
-	if( curitem == LAST_LIST_ITEM ) {
-		curitem = (curitem += LIST_LINES) > LAST_ITEM ?
-			LAST_ITEM : curitem;
-		first_list_item = max(curitem - LIST_LINES + 1, 0);
-		refresh_list();
-	} else {
-		curitem = min(LAST_LIST_ITEM, LAST_ITEM);
-		refresh_curitem(old_curitem);
-	}
+	curitem = curitem == LAST_LIST_ITEM ?
+		((curitem += LIST_LINES) > LAST_ITEM ? LAST_ITEM : curitem) :
+		min(LAST_LIST_ITEM, LAST_ITEM);
+
+	refresh_list();
 }
 
 
-void
-check_list()
-{
-	if( curitem < 0 && first_list_item < 0 && items > 0 )
-		curitem = first_list_item = 0;
-}
-
 void
 select_none()
 {
@@ -259,20 +215,18 @@ move_curitem(int direction)
 void
 goto_home()
 {
-	if(items > 0) {
-		first_list_item = 0;
+	if(items > 0)
 		curitem = 0;
-	}
+	
 	refresh_list();
 }
 
 void
 goto_end()
 {
-	if(items > 0) {
+	if(items > 0)
 		curitem = LAST_ITEM;
-		first_list_item = max(0, curitem - LIST_LINES + 1);
-	}
+
 	refresh_list();
 }
 
